def window_maximize(driver: object) -> None:
    driver.maximize_window()  # type: ignore
